#
# spec file for package suseconnect-ng
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider_prefix github.com/SUSE/connect-ng
%global import_path     %{provider_prefix}

# set this to 1 to enable hwinfo test in %check
%global test_hwinfo 0

Name:           suseconnect-ng
Version:        0.0.8~git0.16545bf
Release:        150400.1.10
URL:            https://github.com/SUSE/connect-ng
License:        LGPL-2.1-or-later
Summary:        Utility to register a system with the SUSE Customer Center
Group:          System/Management
Source:         connect-ng-%{version}.tar.xz
Source1:        %name-rpmlintrc
BuildRequires:  go >= 1.16
BuildRequires:  golang-packaging
BuildRequires:  ruby-devel
BuildRequires:  zypper
%if 0%{?test_hwinfo}
%global test_hwinfo_args -test-hwinfo
# packages required only for hwinfo tests
%ifarch %ix86 ia64 x86_64 %arm aarch64
BuildRequires:  dmidecode
%endif
%ifarch s390x
BuildRequires:  s390-tools
%endif
BuildRequires:  systemd
%endif # test_hwinfo

Obsoletes:      SUSEConnect < 0.3.99
Provides:       SUSEConnect = 0.3.99
Obsoletes:      zypper-migration-plugin < 0.99
Provides:       zypper-migration-plugin = 0.99
Obsoletes:      zypper-search-packages-plugin < 0.99
Provides:       zypper-search-packages-plugin = 0.99
%if 0%{?fedora} || 0%{?rhel} || 0%{?centos_version}
Requires:       ca-certificates
%else
Requires:       ca-certificates-mozilla
%endif
Requires:       coreutils
# ExclusiveArch from this package
%ifarch %ix86 ia64 x86_64 %arm aarch64
Requires:       dmidecode
%endif
# ExclusiveArch from this package
%ifarch s390x
Requires:       s390-tools
%endif
Requires:       zypper
# lscpu is only used on those
%ifarch x86_64 aarch64
Requires:       util-linux
%endif
Recommends:     systemd

%description
This package provides a command line tool for connecting a
client system to the SUSE Customer Center. It will connect the system to your
product subscriptions and enable the product repositories/services locally.
suseconnect-ng reduces the size of its runtime dependencies compared to the
replaced SUSEConnect.


%{go_nostrip}
%{go_provides}

%package -n libsuseconnect
Summary:        C interface to suseconnect-ng.
Group:          System/Management
# the CLI is not used by libsuseconnect but it has the same dependencies and it's easier to keep one list above
Requires:       suseconnect-ng

%description -n libsuseconnect
This package contains library which provides C interface to selected
suseconnect-ng functions.

%package -n suseconnect-ruby-bindings
Summary:        Ruby bindings for libsuseconnect library.
Group:          System/Management
Requires:       libsuseconnect

%description -n suseconnect-ruby-bindings
This package provides bindings needed to use libsuseconnect from Ruby scripts.

%prep
%setup -q -n connect-ng-%{version}

%build
find %_builddir/..
echo %{version} > internal/connect/version.txt
%goprep %{import_path}
find %_builddir/..
go list all
%gobuild suseconnect
mkdir -p %_builddir/go/lib
go build -v -buildmode=c-shared -o %_builddir/go/lib/libsuseconnect.so %import_path/libsuseconnect
find %_builddir/..

%install
%goinstall
ln -s suseconnect %buildroot/%_bindir/SUSEConnect
install -d -m0755 %buildroot/%_sbindir %buildroot/usr/lib/zypper/commands
ln -s %_bindir/suseconnect %buildroot/%_sbindir/SUSEConnect
ln -s %_bindir/suseconnect %buildroot/usr/lib/zypper/commands/zypper-migration
ln -s %_bindir/suseconnect %buildroot/usr/lib/zypper/commands/zypper-search-packages
install -D -m0755 %_builddir/go/lib/libsuseconnect.so %buildroot/%_libdir/libsuseconnect.so
install -d -m0755 %buildroot/%_libdir/ruby/vendor_ruby/%rb_ver
cp -r %_builddir/go/src/%import_path/yast/lib/* %buildroot/%_libdir/ruby/vendor_ruby/%rb_ver
install -D -m 644 %_builddir/go/src/%import_path/man/SUSEConnect.5 %buildroot/%_mandir/man5/SUSEConnect.5
install -D -m 644 %_builddir/go/src/%import_path/man/SUSEConnect.8 %buildroot/%_mandir/man8/SUSEConnect.8
install -D -m 644 %_builddir/go/src/%import_path/man/zypper-migration.8 %buildroot/%_mandir/man8/zypper-migration.8
install -D -m 644 %_builddir/go/src/%import_path/man/zypper-search-packages.8 %buildroot/%_mandir/man8/zypper-search-packages.8

find %_builddir/..
# we currently do not ship the source for any go module
rm -rf %buildroot/usr/share/go

%check
%gotest -v %import_path/internal/connect %{?test_hwinfo_args}
%gotest -v %import_path/suseconnect
make -C %_builddir/go/src/%import_path gofmt

%files
%license LICENSE LICENSE.LGPL
%doc README.md
%_bindir/suseconnect
%_bindir/SUSEConnect
%_sbindir/SUSEConnect
/usr/lib/zypper/commands
%_mandir/man8/*
%_mandir/man5/*

%files -n libsuseconnect
%license LICENSE LICENSE.LGPL
%_libdir/libsuseconnect.so

%files -n suseconnect-ruby-bindings
%doc yast/README.md
%_libdir/ruby/vendor_ruby/%rb_ver/suse

%changelog
* Wed Apr 13 2022 jan.suse@zerebecki.de
- Update to version 0.0.8~git0.16545bf:
  * Allow reloading CA certs pool (bsc#1195220)
* Thu Mar 24 2022 jan.suse@zerebecki.de
- Update to version 0.0.7~git0.3ef988e:
  * Fix product tree traversal (bsc#1197398)
  * Revert "Remove self from LD_PRELOAD (bsc#1196326)"
  * Remove self from LD_PRELOAD (bsc#1196326)
* Tue Mar  1 2022 jan.suse@zerebecki.de
- Update to version 0.0.6~git9.33e5847:
  * Delegate free() calls back to Go (bsc#1195729)
  * Pass "insecure" to zypper addservice
  * Workaround system cert reloading after import (bsc#1195220)
  * Extract setupHTTPClient for easier reuse
  * Exit with code 64 on connection refused like Ruby
* Wed Jan 26 2022 jan.suse@zerebecki.de
- Update to version 0.0.6~git0.77933db:
  * Add man pages
  * Add note in DIFFERENCES.md about abbreviated flags
  * Add -l as an alias for --list-extensions
  * Add --clean as an alias for --cleanup (bsc#1195003)
  * Suppress expected error log message in TLS test
  * Add flag to import product repo keys (bsc#1174657)
* Fri Jan  7 2022 jan.suse@zerebecki.de
- Update to version 0.0.5~git0.bbb5544:
  * Switch from rubygem-ffi to fiddle
  * Cleanup services during migration (bsc#1161891)
  * Allow non-root users to see usage text
  * Add option to not fail dup as much
  * Move APIVersion declaration to file where it is used
  * Add flag to enable/disable hwinfo test
  * Add ARM cluster count to hwinfo and fix test
  * Simplify parsing JSON error response
  * Add --gpg-auto-import-keys for zypper ref
  * Rename main.go to logging.go
  * Fix typo
  * Remove init() from the connect package
  * Move CFG variable declaration to config.go
  * Move AppName const to the file where it is used
  * Use testing.Helper() in test helpers
  * Add ppc64le support
  * Disable UUID test
  * Add test tools to BuildRequires
  * Ignore UUID errors
  * Run basic hwinfo sanity test on build service
  * Update code comments to match shim behavior.
  * Remove dependency on systemd
  * Only run httputil DumpResponse when needed
* Wed Dec  1 2021 jan.suse@zerebecki.de
- Update to version 0.0.4~git0.64b80e9:
  * Makefile: also run tests under ./suseconnect
  * Switch yast-test to upstream
  * Removed examples leftover from the POC phase
  * Add HA repo to get rubygem(ffi) before it's in the baseproduct
  * Add versions and lib deps
  * Post-review cleanup
  * Package libsuseconnect and shim
  * Align with yast-registration tests
  * Fix SSLCertificate mixins
  * Fix logger crash and restore mixin
  * Removed TODO item handled separately
  * Enable debug early
  * Add package search for YaST's "Online Search"
  * Clarify Repo fields
  * Export UpdateSystem()
  * Export SystemActivations()
  * Add migration functions
  * Fix handling of IsBase attribute
  * Add missing JSONError
  * Add list_installer_updates
  * Add "update certificates"
  * Add more specific errors
  * Improved SSL error handling
  * Init defaults for get_config()
  * Improved debug logging
  * Fix error scopes
  * Fix ApiError interface
  * Added DEFAULT_CREDENTIALS_DIR const
  * get proxy credentials from curlrc
  * Forward logs from Connect to YaST
  * Separate Info logger
  * Added more TODO items
  * Simplify Config object init
  * Map Repo and Config fields to JSON
  * Add remaining fields listed in addon.rb
  * Add product_type field to product
  * First working yast part
  * Add relative path support to credentials
  * Add steps to test from yast
  * Add yast create_credentials_file
  * Add CreateCredentials() method
  * Add yast credentials()
  * Add yast announce_system - WIP
  * Add MergeJSON method for Config
  * Add readme for YaST integration
  * Fix usage text
  * Add missing -g argument
  * Fix OBS CI, it now requires target
  * Add manpage placeholder
  * Simplify packageWanted()
  * Add sorting and grouping options
  * Add local repo search and duplicate removal
  * Add basic online package search
  * Update rpm spec for zypper-search-packages-plugin
  * Add CLI for zypper search-packages plugin
  * Optional base product in package search
  * Use DefaultTransport defaults + client timeout
  * Extract ReleaseType from zypper output
  * Print failed command on zypper error like the Ruby
  * Add package_search API wrapper
  * Allow de-register/de-activate a single product
  * Improve docstring for the Status struct
  * Always show subscription information if available
  * Refactor getStatuses() to ease testing
  * Add SUMA/Uyuni check
  * Fix status output order to follow zypper product xml
  * Change GetExtensionsList() to reduce calls
  * Add the subscription name to status output
  * allow --instance-data together with --regcode
  * Post-review cleanups
  * Add selfupdate functionality
  * Handle Leap -> SLES migration scenario
  * Add offline migrations support
  * Change parse error string and add block comment
  * Add disabling of obsolete repos
  * Add zypper repos listing
  * Add interactive migration selection
  * Allow loading Config from any path
  * Remove dummy flag
  * Add snapper support
  * Add zypper backup/restore functions
  * Use connect.StringSet
  * Add --query option
  * Add product and break-my-system options
  * Add note on conflicting flags
  * Check for flag contradictions
  * Add echoing output of executed commands to console
  * Move product printing out of checkProducts()
  * Split --debug and --verbose
  * Add zypper dist-upgrade part
  * Split migration code
  * Extract migration sorting
  * Expose migration(Add|Remove)Service() functions
  * Trap SIGINT/SIGTERM
  * Add zypper.RefreshRepos()
  * Expose client.upgradeProduct()
  * Add --root parameter
  * Add --migration N parameter
  * Prepare available migrations
  * Add API call to get online migration paths
  * Add system products checking
  * Add quiet logger for easier --quiet handling
  * Add zypper migration plugin implementation.
  * Export toTriplet and installReleasePackage
  * Add basic string set implementation
  * Remove quiet param from execute() and zypperRun()
  * Simplify mocking of external commands
* Fri Aug 27 2021 jzerebecki@suse.com
- Update to version 0.0.3~git9.19e761b:
  * Add zypper-migration-plugin to package
  * Remove unused Error logger
  * Add missing doc strings to exported vars and funcs
  * Handle error after products sync api call
  * Make the CI check gofmt
* Tue Jul 27 2021 jzerebecki@suse.com
- Update to version 0.0.3~git0.dacdd3b:
  * Add gofmt target to Makefile
  * Fix gofmt errors
  * Add Requires that weren't explicit (bsc#1188646)
  * Use custom UnmarshalJSON() for the Product struct
* Fri Jul 23 2021 jzerebecki@suse.com
- Update to version 0.0.2~git0.ebef3b7:
  * Add --version
  * Fix list-extensions printing "Not available" when using SCC
  * Change --deregister to --de-register
* Thu Jul 22 2021 jzerebecki@suse.com
- Update to version 0.0.1~git33.b531281:
  * Run integration tests
  * Try to use localized error from server response
  * Write usage help to stdout like the Ruby version
  * Simplify list-extensions template
  * Fix call to create UUID on s390
  * Provides and Obsoletes SUSEConnect
  * Add extensions list tests
  * Fix calls to s390 read_values
  * Add build-s390 target to Makefile
  * hwinfo: don't fail if dmidecode is missing
* Mon Jul 19 2021 jzerebecki@suse.com
- Update to version 0.0.1~git16.8a5d48c:
  * Add extensions hints for readonly root fs
  * Make the connect package an internal package
  * Document debug output destination difference
  * Add status value constants
  * Add rollback CLI option
  * Fix callHTTP() so connections are reused
  * Fix list-extensions format
  * Fix error from zypper refresh
* Mon Jul 12 2021 jzerebecki@suse.com
- Update to version 0.0.1~git0.a5f168a:
  * Add JSONError and cleanup error handling
* Fri Jul  9 2021 jzerebecki@suse.com
- Update to version 0.0.0~git.c45760f:
  * Add Conflicts:SUSEConnect due to same file name
  * Document advantage of suseconnect-ng
  * Make UpdateSystem() message text bold
  * Add no_zypper_refs config file option
  * Complete Register() and AnnounceSystem()
  * Add registerProductTree()
  * Add activateProduct() and registerProduct()
  * Rename source modules to executable names
  * Remove unnecessary content from package.
  * Add proxy auth support
  * Change order of usage help options to match the Ruby version
  * Make requirement for go 1.16 explicit.
  * Fix instance data file path
  * Add zypper service commands needed for registration
  * S390: set cpus, sockets, hypervisor and uuid hwinfo fields
  * Implement the system update part of registration
  * Add helper to build hwinfo struct
  * Add functions to call and parse s390 read_values
  * Add function to get the hostname
  * Add function to get private IP address
  * Add arch, hypervisor and uuid functions
  * Add function to find cloud provider from dmidecode
  * Add function to parse lscpu output
  * Add announceSystem() api call
  * Add deregistration functionality
  * Add deactivateProduct() API call
  * obs: use an in between branch
* Fri Jul  2 2021 jzerebecki@suse.com
- Update to version 0.0.0~git.a083a1f:
  * Add Product.IsEmpty()
  * Add unit test for token auth
  * Add obs workflow to be able to use it as CI
  * add files to build rpm
  * Add more zypper operations
  * Unexport api functions
  * Add --cleanup CLI action
  * Add listing of installed services via zypper
  * Change zypperRun args to take a slice of strings
  * Fix printInformation() outputs
* Fri Jun 25 2021 jzerebecki@suse.com
- Initial package of suseconnect-ng
